@@ -3,9 +3,6 @@ import pytz
 import uuid
 
 
-from arcane.datastore import Client
-
-from arcane import pubsub
 from .log import adscale_log
 from .services import ServiceEnum
 from arcane.datastore import Client as DatastoreClient
